package com.etc.dbutil;

import java.io.IOException;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Properties;

public class DBManager {

	private Connection conn = null;	
	private PreparedStatement pstmt = null;
	
	private static Properties prop = new Properties();

	private static String dbDriver = "";
	private static String dbUrl = "";
	private static String dbUsername = "";
	private static String dbPassword = "";
		
		static{
		
		try {
			prop.load(DBManager.class.getResourceAsStream("dbconfig.properties"));
			
			dbDriver = prop.getProperty("dbDriver");
			dbUrl = prop.getProperty("dbUrl");
			dbUsername = prop.getProperty("dbUsername");
			dbPassword = prop.getProperty("dbPassword");
					
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
	public DBManager(){
		
		try {
			Class.forName(dbDriver);

			this.conn = DriverManager.getConnection(dbUrl, dbUsername, dbPassword);
			
		} catch (ClassNotFoundException e) {
			e.printStackTrace();
		} catch (SQLException e) {
			e.printStackTrace();
		}
	}

	public int execUpdate(String sql, Object... params){
				
		try {
			
			this.pstmt = this.conn.prepareStatement(sql);
			
			for (int i = 0; i < params.length; i++) {
				this.pstmt.setObject(i+1, params[i]);			
			}
			
			return this.pstmt.executeUpdate();
			
		} catch (SQLException e) {
			e.printStackTrace();
			return  -1;
		}		
	}
	
	public ResultSet execQuery(String sql, Object... params){
		
		try {
			
			this.pstmt = this.conn.prepareStatement(sql);
			
			for (int i = 0; i < params.length; i++) {
				this.pstmt.setObject(i+1, params[i]);			
			}
			
			return pstmt.executeQuery();
			
		} catch (SQLException e) {
			e.printStackTrace();
			return null;
		}		
	}
	
		public void close(){
		
		if(this.pstmt != null){
			try {
				this.pstmt.close();
			} catch (SQLException e) {
				e.printStackTrace();
			}			
		}
	
		
		if(this.conn != null){
			try {
				this.conn.close();
			} catch (SQLException e) {
				e.printStackTrace();
			}			
		}
	}
	
	public static void main(String[] args) {

				
		DBManager dbManager = new DBManager();

		String sql = "";
		int rows = 0;
	
		
		sql = "select * from user";
				
		ResultSet rs = dbManager.execQuery(sql);
		
		try {
			while(rs.next()){
				System.out.println(rs.getString(2) + "-" + rs.getString(3) + "-" + rs.getInt(4));
			}
		} catch (SQLException e) {
			e.printStackTrace();
		}		

		try {
			rs.close();
		} catch (SQLException e) {
			e.printStackTrace();
		}

		dbManager.close();
	}

}
